# PEQNP
General Constrained Diophantine Equation Solver v0.1.29

pip3 install PEQNP

Documentation www.peqnp.science

Examples https://github.com/maxtuno/PEQNP

More info:

Twitter Account
https://twitter.com/maxtuno

Youtube Channel
https://www.youtube.com/channel/UCFlk1dUYLKtymcoMScdynNA

version 0.1.30
- Add support for android, ARM C++ compilation.
- Add version() function that return the current version of the system.
- Add proof_path parameter to satisfy(), this generate the DRUP-PROOF of the problem if its is unsatisfiable.

version 0.1.31
- Fix URL on SLIME log.